==> open-xchange-mobile-api-facade_1.2.5.orig.tar.bz2: open-xchange-mobile-api-facade-1.2.5/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/utils/AccountUtil.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.utils;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import com.openexchange.java.Strings;
import com.openexchange.mobile.api.facade.connectors.responses.mtos.UserMto;

import lombok.experimental.UtilityClass;

@UtilityClass
public class AccountUtil {

    public String getUserName(String personalName, UserMto userMto) {
        String userName;
        if (userMto == null) {
            return personalName;
        }
        String firstName = userMto.getFirstName();
        String lastName = userMto.getLastName();
        if (firstName != null || lastName != null) {
            if (firstName == null) {
                userName = lastName;
            } else if (lastName == null) {
                userName = firstName;
            } else {
                userName = firstName + " " + lastName;
            }
        } else {
            userName = Strings.isEmpty(personalName) ? userMto.getDisplayName() : personalName;
        }
        return userName;
    }

    public List<String> getAliases(String primaryAddress, String aliasesStr) {
        if (Strings.isEmpty(aliasesStr)) {
            return null;
        }
        String[] splittedAliases = aliasesStr.split(",");
        for (int index = 0; index < splittedAliases.length; index++) {
            splittedAliases[index] = splittedAliases[index].trim();
        }
        List<String> aliases = new ArrayList<>(Arrays.asList(splittedAliases));
        while (aliases.remove(primaryAddress)) {
            // Nothing to do.
        }
        return aliases.isEmpty() ? null : aliases;
    }

}

==> open-xchange-mobile-api-facade_1.8.4.orig.tar.bz2: open-xchange-mobile-api-facade-1.8.4/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/utils/AccountUtil.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.utils;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import com.openexchange.java.Strings;
import com.openexchange.mobile.api.facade.connectors.responses.mtos.UserMto;

import lombok.experimental.UtilityClass;

@UtilityClass
public class AccountUtil {

    public String getUserName(String personalName, UserMto userMto) {
        // Prefer personal name from mail account.
        if (Strings.isNotEmpty(personalName)) {
            return personalName;
        }

        // Build name from firstName and lastName of user.
        String userName;
        String firstName = userMto.getFirstName();
        String lastName = userMto.getLastName();
        if (Strings.isNotEmpty(firstName) || Strings.isNotEmpty(lastName)) {
            if (Strings.isEmpty(firstName)) {
                userName = lastName;
            } else if (Strings.isEmpty(lastName)) {
                userName = firstName;
            } else {
                userName = firstName + " " + lastName;
            }
        } else {
            // Fallback to display name.
            userName = userMto.getDisplayName();
        }
        return userName;
    }

    public List<String> getAliases(String primaryAddress, String aliasesStr) {
        if (Strings.isEmpty(aliasesStr)) {
            return null;
        }
        String[] splittedAliases = aliasesStr.split(",");
        for (int index = 0; index < splittedAliases.length; index++) {
            splittedAliases[index] = splittedAliases[index].trim();
        }
        List<String> aliases = new ArrayList<>(Arrays.asList(splittedAliases));
        while (aliases.remove(primaryAddress)) {
            // Nothing to do.
        }
        return aliases.isEmpty() ? null : aliases;
    }

}
